; *******************************************************************
; *********            Wall.lsp		     ************************
; ********* Disegno di un muro di sostegno   ************************
; ********* Programma scritto da Marco Monni ************************
; ********* Ver 5.03 - Aprile 2001           ************************
; *********                                  ************************
; *********  Ottimizzato per Acad 2000       ************************
; *********                                  ************************
; *********         FREEWARE VERSION         ************************
; *********                                  ************************
; *******************************************************************
; *******************************************************************
;
; Le definizioni della finestra di dialogo sono nel file wall.dcl
; L'immagine slide  nel file wall_image.sld
;
; *******************************************************************   
; Rispetto alla versione 4.0  ora visualizzata la distinta dei ferri d'armatura
; *******************************************************************

(defun c:wall (/ dcl_id 
                 Dialog_Status
               )

  ; viene richiesto il punto di inserimento del muro
  (setq pu (getpoint "\nPunto inserimento: "))

  ;--------------------------------------------------------------------------------------------
  ; viene caricata l'interfaccia di dialogo wall.dcl posta in una directory "support" di Autocad

  (setq dcl_id (load_dialog "wall.dcl"))
  (if (not (new_dialog "wall" dcl_id) ) (exit)) ; controllo per eventuali errori

  ;--------------------------------------------------------------------------------------------  
  ; viene caricata, all'interno della finestra di dialogo, la diapositiva wall_slide.sld posta nella directory "support" di Autocad

  (setq x (dimx_tile "Diapositiva muro")
        y (dimy_tile "Diapositiva muro"))
  (start_image "Diapositiva muro")
  (slide_image 0 0 (+ x 180) (- y 40) "wall_slide")
  (end_image)

  ;--------------------------------------------------------------------------------------------
  ; vengono fissati nelle caselle della finestra di dialogo dei valori iniziali per i parametri di disegno del muro. Questo per evitare che le caselle risultino completamente vuote all'avvio.

  (set_tile "h" "250") 
  (set_tile "a" "30") 
  (set_tile "p" "50") 
  (set_tile "b" "70") 
  (set_tile "c" "120") 
  (set_tile "d" "40") 
  (set_tile "s2" "30") 
  (set_tile "s1" "30") 
  (set_tile "fi" "14")
  (set_tile "nf" "4")  
  (set_tile "cf" "5")
  (set_tile "sc" "25")

  ;--------------------------------------------------------------------------------------------
  ; funzione di disegno "draw_wall" -  la funzione che consente l'intero disegno del muro.

  (defun draw_wall ()

    ; viene abilitato il layer "0" come layer corrente

    (command "_-layer"
             "_set"
             0
             end
     )

    ; viene disattivato lo snap
   
    (command "_-osnap"
             "_off"
    )

    ; vengono fissate le coordinate del perimetro esterno del muro    
  
    (setq     x1  (car pu)  
              y1  (car (cdr pu))         
              x2  (+ x1  a)
              y2  (car (cdr pu))
              x3  (+ x1  a)
              y3  (- y2 h)
              x4  (+ x3 c)
              y4  (- y2 h)
              x5  (+ x3 c)
              y5  (- y4 (+ d s2))
              x6  (- x5 s1)
              y6  (- y4 (+ d s2))
              x7  (- x5 s1)
              y7  (+ y6 s2)
              x8  (- x2 (+ b p))
              y8  (+ y6 s2)
              x9  (- x2 (+ b p))
              y9  (+ y8 d)
              x10 (- x3 p)
              y10 (+ y8 d) 
      )

    ; vengono definite le coordinate del punto 11

    (setq     m1  (- y7 y1)
              m2  (- x10 x1)
              m3  (- y10 y1)
              m4  (/ m2 m3)
              x11 (+ (* m1 m4) x1)
              y11 (+ y6 s2)
    )
    
    ; a ciascuna coppia di coordinate viene associato un punto
    
    (setq p1 (list x1 y1)
          p2 (list x2 y2)
          p3 (list x3 y3)
          p4 (list x4 y4)
          p5 (list x5 y5)
          p6 (list x6 y6)
          p7 (list x7 y7)
          p8 (list x8 y8)
          p9 (list x9 y9)
          p10 (list x10 y10)
          p11 (list x11 y11)

    )

    ; vengono uniti i punti del perimetro esterno tramite una polilinea

    (command "_pline" 
              p1 
              p2 
              p3 
              p4
              p5 
              p6
              p7
              p8
              p9
              p10
              "_c"
    )

    ; vengono create le coordinate dei punti per il perimetro del magrone

    (setq    xm1 (- x8 8)
             ym2 (- y8 8) 
             xm3 (- x7 8)
             ym4 (- y6 8)
             xm5 (+ x5 8)
    )

    ; vengono creati i punti per il perimetro del magrone

    (setq    m1 (list xm1 y8)
             m2 (list xm1 ym2)
             m3 (list xm3 ym2)
             mm4(list xm3 ym4)
             m5 (list xm5 ym4)
             m6 (list xm5 y5)
             m7 (list x5 y5)
    )

    ; vengono uniti i punti del magrone tramite una polilinea

    (command "_pline" 
             p8
             m1
             m2
             m3
             mm4
             m5
             m6
             m7
             ""
     )        

    ; viene creato il layer "1", di colore blu, in cui verranno disegnati i ferri d'armatura

    (command "_-layer"
             "_make"
             1
             "_color"
             5
             1
             end
     )

     ; vengono fissate le coordinate dei ferri d'armatura interni al muro

     (setq    xa1  (+ x1 cf)
              ya1  (- y1 cf)
              xa2  (- x2 cf)
              ya2  (- y1 cf)
              xa3  (- x3 cf)
              ya3  (+ y7 cf)
              xa4  (+ x11 cf)
              ya4  (+ y7 cf)
              xa5  (+ x9 cf)
              ya5  (+ y7 cf)
              xa6  (+ x9 cf)
              ya6  (- y9 cf)
              xa7  (- x5 cf)
              ya7  (- y9 cf)
              xa8  (- x5 cf)
              ya8  (+ y7 cf)
              xa9  (- x5 cf)
              ya9  (+ y5 cf)
              xa10 (+ x6 cf)
              ya10 (+ y5 cf)
              xa11 (+ x6 cf)
              ya11 (- y9 cf)
    )

    ; a ciascuna coppia di coordinate viene associato un punto

    (setq    a1  (list xa1 ya1)
             a2  (list xa2 ya2)
             a3  (list xa3 ya3)
             a4  (list xa4 ya4)
             a5  (list xa5 ya5)
             a6  (list xa6 ya6)
             a7  (list xa7 ya7)
             a8  (list xa8 ya8)
             a9  (list xa9 ya9)
             a10 (list xa10 ya10)
             a11 (list xa11 ya11)
    )

   ; vengono uniti i punti dei ferri d'armatura interni

    (command "__pline" a1 a2 a3 a4 "_c")
    (command "__pline" a6 a7 a8 a5 "_c")
    (if (and (> s2 0) (> s1 0))(command "_pline" a7 a9 a10 a11 _"c"))

   ; vengono fissate le coordinate dei ferri d'armatura interni al muro

     (setq    xb1  (+ xa8 50)
              yb1  (+ y3 0)
              xb2  (+ xb1 (- xa1 xa4))
              yb2  (- y1 cf)
              xb3  (+ xb2 (- xa2 xa1))
              yb3  (- y1 cf)


              xb5  (+ xb1 40)
              yb5  (+ y7 cf)
              xb6  (+ xb5 (- xa3 xa4))
              yb6  (+ y7 cf)
              xb7  (+ xb5 (- xa3 xa4))
              yb7  (+ ya4 (* 3 d))
              m5   (- yb7 y1)
              xm6  (+ (* m5 m4) x1)
              xb4 (+ xb5 (- xm6 x10))
              yb4  (+ ya4 (* 3 d))

              xb8  (+ xb6 40)
              yb8  (+ y3 0)
              xb9  (+ xb6 40)
              yb9  (- y1 cf)
              xb10 (- xb9 (- xa2 xa1))
              yb10 (- y1 cf)

              xb11 (+ x9 cf)
              yb11 (- (- ya9 70) (- ya6 ya5))
              xb12 (+ x9 cf)
              yb12 (- ya9 70)
              xb13 (- x5 cf)
              yb13 (- ya9 70)
              xb14 (- x5 cf)
              yb14 (- yb12 (- ya6 ya5))

              xb15 (+ x9 cf)
              yb15 (- yb11 20)
              xb16 (+ x9 cf)
              yb16 (- yb15 (- ya6 ya5))
              xb17 (- x5 cf)
              yb17 (- yb15 (- ya6 ya5))
              xb18 (- x5 cf)
              yb18 (- yb11 20)

              xb19 (+ x6 cf)
              yb19 (+ ya11 50)
              xb20 (+ xb19 (- xa7 xa11))
              yb20 (+ yb19 (- ya7 ya9))
              xb21 (- xb20 2)
              yb21 (+ yb19 (- ya7 ya9))
              xb22 (- xb20 2)
              yb22 (- yb21 10)

              xb23 (+ x1 cf)
              yb23 (- ya1 1.0)
              xb24 (+ xb23 (* 2 1.0))
              yb24 (- ya1 1.0)
              yb25 (- ya1 (+ 1 20))        ; 20  l'interasse tra i ripartitori
              yb27 (- ya1 (+ 1 (* 2 20)))  ; 20  l'interasse tra i ripartitori
              xb29 (- xa2 2)
              xb35 (+ xa5 1)
              yb36 (+ ya5 (* 2 1.0))
              xb37 (+ xa5 (+ 1 20))        ; 20  l'interasse tra i ripartitori
              xb39 (+ xa5 (+ 1 (* 2 20)))  ; 20  l'interasse tra i ripartitori
              yb41 (- ya6 (* 2 1.0)) 
      )

    ; a ciascuna coppia di coordinate viene associato un punto
    
    (setq    b1  (list xb1 yb1)
             b2  (list xb2 yb2)
             b3  (list xb3 yb3)
             b4  (list xb4 yb4)
             b5  (list xb5 yb5)
             b6  (list xb6 yb6)
             b7  (list xb7 yb7)
             b8  (list xb8 yb8)
             b9  (list xb9 yb9)
             b10 (list xb10 yb10)
             b11 (list xb11 yb11)
             b12 (list xb12 yb12)
             b13 (list xb13 yb13)
             b14 (list xb14 yb14)
             b15 (list xb15 yb15)
             b16 (list xb16 yb16)
             b17 (list xb17 yb17)
             b18 (list xb18 yb18)
             b19 (list xb19 yb19)
             b20 (list xb20 yb20)
             b21 (list xb21 yb21)
             b22 (list xb22 yb22)
             b23 (list xb23 yb23)
             b24 (list xb24 yb24)
             b25 (list xb23 yb25)
             b26 (list xb24 yb25)
             b27 (list xb23 yb27)
             b28 (list xb24 yb27)
             b29 (list xb29 yb23)
             b30 (list xa2  yb23)
             b31 (list xb29 yb25)
             b32 (list xa2  yb25)
             b33 (list xb29 yb27)
             b34 (list xa2  yb27)
             b35 (list xb35 ya5 )
             b36 (list xb35 yb36)
             b37 (list xb37 ya5 )
             b38 (list xb37 yb36)
             b39 (list xb39 ya5 )
             b40 (list xb39 yb36)
             b41 (list xb35 yb41)
             b42 (list xb35 ya6 )
             b43 (list xb37 yb41)
             b44 (list xb37 ya6 )
             b45 (list xb39 yb41)
             b46 (list xb39 ya6 )

    )

  ; vengono disegnati i ferri d'armatura sfilati

    (command "_pline" b1 b2 b3 "")
    (command "_pline" b4 b5 b6 b7 "")
    (command "_pline" b8 b9 b10 "")
    (command "_pline" b11 b12 b13 b14 "")
    (command "_pline" b15 b16 b17 b18 "")
    (if (and (> s2 0) (> s1 0)) (command "_rectang" b19 b20)); se s2 e s1 sono maggiori di zero disegna la staffa del dente
    (if (and (> s2 0) (> s1 0)) (command "_line" b21 b22 "")); //
    (command "_circle" "2p" b23 b24)
    (command "_circle" "2p" b29 b30)
    (command "_circle" "2p" b31 b32)
    (command "_circle" "2p" b33 b34)
    (command "_circle" "2p" b35 b36)
    (command "_circle" "2p" b37 b38)
    (command "_circle" "2p" b39 b40)
    (command "_circle" "2p" b41 b42)
    (command "_circle" "2p" b43 b44)
    (command "_circle" "2p" b45 b46)

  ; viene creato il layer "2", di colore ciano, in cui verranno poste le quote

    (command "_-layer"
             "_make"
             2
             "_color"
             4
             2
             _end
     )

  ; quotatura del muro

    (command "_dim"
             "_dimtxt" 0.18 ""
             "_dimasz" 0.18 ""
             "_dimgap" 0.07 ""
             "_dimexe" 0.18 ""
             "_dimexo" 0.60 ""
             "_dimtofl" 1 "1"
             "_dimdec" 2 ""
             "_dimtih" 0 ""
             "_dimtoh" 0 ""
             "_dimscale" sc ""
             "_hor" p1 p2  (list x1 (+ 20 y1))  ""
             "_hor" (list x10 y6) (list x3 y6) (list x7 (- y6 20))  ""
             "_hor" (list x9 y6) (list x10 y6) (list x7 (- y6 20))  ""
             "_hor" (list x8 y6) (list x5 y6)  (list x7 (- y6 35)) ""
             "_ver" p8 p9  (list (- x9 40) y9)  ""
             "_ver" (list x8 y1) p9  (list (- x9 40) y9)  ""
             "_leader" (list (- xa4 10) ya6) (list (- xa4 20) (+ ya6 50)) (list (- xa4 25) (+ ya6 50))"" "Pos. 1-2"
             "_leader" (list (- xa4 25) ya5) (list (- xa4 20) (+ ya6 50)) (list (- xa4 25) (+ ya6 50))"" "Pos. 1-2"
             "_leader" (list (+ xm6 cf) yb4) (list (- xm6 10) (+ 15 (- ya1 (/ (- ya1 ya6) 2)))) (list (- xm6 15) (+ 15 (- ya1 (/ (- ya1 ya6) 2))))"" "Pos. 4"  
             "_leader" (list xa3 (- ya1 (/ (- ya1 ya6) 2))) (list (+ xa3 10) (+ 40 (- ya1 (/ (- ya1 ya6) 2)))) (list (+ xa3 15) (+ 40 (- ya1 (/ (- ya1 ya6) 2))))"" "Pos. 5"
             "_leader" b23 (list (- xa1 20) (+ yb25 30)) (list (- xa1 25) (+ yb25 30)) "" "Ripartitori 1%%C10/20"
             "_leader" b29 (list (- xa1 20) (+ yb25 30)) (list (- xa1 25) (+ yb25 30)) "" "Ripartitori 1%%C10/20" 
             "_exit"
             ;"_text" "_j" "_c" (list (- xa1 23) (+ yb25 33)) (* 0.18 sc) 0 (fix in) ""
    )

  ; quotatura della mensola a monte se c' il dente di fondazione
  ; *************************************************************
  (if (and (> s2 0) (> s1 0)) (command "_dim" "_hor" p3 p4  (list x3 (+ 20 y3))  "" "_exit"))

  ; quotatura, in posizione diversa, della mensola a monte se NON c' il dente di fondazione
  ; *************************************************************
  (if (and (= s2 0) (= s1 0)) (command "_dim" "_hor" (list x2 y6) (list x5 y6)  (list x7 (- y6 20))  "" "_exit"))

  ; leader della pos. 3 se c' il dente di fondazione
  ; *************************************************************
  (if (and (> s2 0) (> s1 0)) (command "_dim" "_leader" (list xa4 (+ ya4 (/ (- ya6 ya5) 2))) (list (- xa4 10) (- ya4 31)) (list (- xa4 15) (- ya4 31))"" "Pos. 3" "_exit"))

  ; leader della pos. 3 se NON c' il dente di fondazione
  ; *************************************************************
  (if (and (= s2 0) (= s1 0)) (command "_dim" "_leader" (list xa3 (+ ya4 (/ (- ya6 ya5) 2))) (list (+ xa3 30) (+ ya6 30)) (list (+ xa3 35) (+ ya6 30))"" "Pos. 3" "_exit"))

  ; quotatura del "dente"

  (if (and (> s2 0) (> s1 0)) (command "_dim" "_hor" p6 p5  (list x7 (- y6 20))  "" "_exit"))
  (if (and (> s2 0) (> s1 0)) (command "_dim" "_hor" (list x3 y6) (list x7 y6) (list x7 (- y6 20)) "" "_exit"))
  (if (and (> s2 0) (> s1 0)) (command "_dim" "_ver" p4 p5  (list (+ x5 20) y5)  "" "_exit"))
  (if (and (> s2 0) (> s1 0)) (command "_dim" "_ver" p8 (list x8 y6) (list (- x9 40) y8)  "" "_exit"))

  ; vengono contrassegnate le posizioni dei ferri

  (setq di (+ 3 (* 0.18 sc))); distanza della scritta dal bordo del ferro

  ; ferri della posizione n. 1
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2)) (+ yb12 3)) (* 0.18 sc) 0 "Pos.1 -  %%C  /mt LT=")
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2) (* -1.2 di)) (+ yb12 3)) (* 0.18 sc) 0 (rtos nf 2 0)); numero ferri "nf"
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2) (* 0.7 di)) (+ yb12 3)) (* 0.18 sc) 0 (rtos fi 2 0)); scrive il diametro
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2) (* (* 0.18 sc) 11)) (+ yb12 3)) (* 0.18 sc) 0 (fix(+ (distance b11 b12) (distance b12 b13) (distance b13 b14)))); scrive la lunghezza totale del ferro in pos. 1
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2)) (- yb12 di)) (* 0.18 sc) 0 (fix(distance b12 b13)))
  (command "_text" "_j" "_c" (list (+ xb12 di) (+ yb11 (/ (distance b11 b12) 2))) (* 0.18 sc) 90 (fix(distance b11 b12)))
  (command "_text" "_j" "_c" (list (- xb14 2) (+ yb11 (/ (distance b11 b12) 2))) (* 0.18 sc) 90 (fix(distance b13 b14)))   

  ; ferri della posizione n. 2
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2)) (- yb16 di)) (* 0.18 sc) 0 "Pos.2 -  %%C  /mt LT=")
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2) (* -1.2 di)) (- yb16 di)) (* 0.18 sc) 0 (rtos nf 2 0)); numero ferri "nf"
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2) (* 0.7 di)) (- yb16 di)) (* 0.18 sc) 0 (rtos fi 2 0)); scrive il diametro
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2)(* (* 0.18 sc) 11)) (- yb16 di)) (* 0.18 sc) 0 (fix(+ (distance b15 b16) (distance b16 b17) (distance b17 b18)))); scrive la lunghezza totale del ferro in pos. 2
  (command "_text" "_j" "_c" (list (+ xb12 (/ (- xb13 xb12) 2)) (+ yb16 3)) (* 0.18 sc) 0 (fix(distance b12 b13)))
  (command "_text" "_j" "_c" (list (+ xb12 di) (+ yb16 (/ (distance b16 b15) 2))) (* 0.18 sc) 90 (fix(distance b16 b15)))
  (command "_text" "_j" "_c" (list (- xb14 2) (+ yb16 (/ (distance b16 b15) 2))) (* 0.18 sc) 90 (fix(distance b16 b15)))

  ; ferri della posizione n. 3
  (command "_text" "_j" "_c" (list (+ xb5 (/ (distance b5 b6) 2)) (- yb5 (* di 2.5))) (* 0.18 sc) 0 "Pos.3 -  %%C  /mt LT=")
  (command "_text" "_j" "_c" (list (+ xb5 (/ (distance b5 b6) 2) (* -1.2 di)) (- yb5 (* di 2.5))) (* 0.18 sc) 0 (rtos nf 2 0)); numero ferri "nf"
  (command "_text" "_j" "_c" (list (+ xb5 (/ (distance b5 b6) 2) (* 0.7 di)) (- yb5 (* di 2.5))) (* 0.18 sc) 0 (rtos fi 2 0)); diametro
  (command "_text" "_j" "_c" (list (+ xb5 (/ (distance b5 b6) 2) (* (* 0.18 sc) 11)) (- yb5 (* di 2.5))) (* 0.18 sc) 0 (fix(+ (distance b4 b5) (distance b5 b6) (distance b6 b7)))); scrive la lunghezza totale del ferro in pos. 3
  (command "_text" "_j" "_c" (list (+ xb5 (/ (distance b5 b6) 2)) (- yb5 di)) (* 0.18 sc) 0 (fix(distance b5 b6)))      
  (command "_text" "_j" "_c" (list (- xb5 2) (+ yb5 (/ (distance b5 b4) 2))) (* 0.18 sc) 90 (fix(distance b5 b4)))
  (command "_text" "_j" "_c" (list (+ xb6 di) (+ yb6 (/ (distance b6 b7) 2))) (* 0.18 sc) 90 (fix(distance b6 b7)))

  ; ferri posizione n. 4
  (setq l1 (+ yb1 (/ (- yb2 yb1) 2))
        l2 (- l1 yb2)
        l3 (- yb1 yb2)
        l4 (- xb1 xb2)
        xl (+ (* (/ l2 l3) l4) xb2)

        n1 (+ yb1 (/ (distance b1 b2) 2) (* (* 0.18 sc) 11))
        n2 (- n1 yb2)
        xn (+ (* (/ n2 l3) l4) xb2) 
  )

  (command "_text" "_j" "_c" (list (- xl 3) l1) (* 0.18 sc) (list (- xb2 3) yb2) "Pos.4 -  %%C  /mt LT=")
  (command "_text" "_j" "_c" (list (- xl 3) (+ l1 -9.0)) (* 0.18 sc) (list (- xb2 3) yb2) (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" "_j" "_c" (list (- xl 3) (+ l1 4.0)) (* 0.18 sc) (list (- xb2 3) yb2) (rtos fi 2 0)); scrive il diametro
  (command "_text" "_j" "_c" (list (- xn 3) n1) (* 0.18 sc) (list (- xb2 3) yb2) (fix(+ (distance b8 b9) (distance b9 b10)))); scrive la lunghezza totale del ferro in pos. 4
  (command "_text" "_j" "_c" (list (+ xl di) l1) (* 0.18 sc) (list (+ xb2 3) yb2) (fix(distance b8 b9)))
  (command "_text" "_j" "_c" (list (+ xb2 (/ (distance b2 b3) 2)) (- yb2 di)) (* 0.18 sc) 0 (fix(distance b10 b9)))

  ; ferri posizione n. 5
  (command "_text" "_j" "_c" (list (+ xb8 di) (+ yb1 (/ (distance b1 b2) 2))) (* 0.18 sc) 90 "Pos.5 -  %%C  /mt LT=" "")
  (command "_text" "_j" "_c" (list (+ xb8 di) (+ yb1 (/ (distance b1 b2) 2) (* -1.2 di))) (* 0.18 sc) 90 (rtos nf 2 0)); numero ferri nf
  (command "_text" "_j" "_c" (list (+ xb8 di) (+ yb1 (/ (distance b1 b2) 2) (* 0.7 di))) (* 0.18 sc) 90 (rtos fi 2 0)); scrive il diametro
  (command "_text" "_j" "_c" (list (+ xb8 di) (+ yb1 (/ (distance b1 b2) 2) (* (* 0.18 sc) 11))) (* 0.18 sc) 90 (fix(+ (distance b8 b9) (distance b9 b10))) ""); scrive la lunghezza totale del ferro in pos. 5
  (command "_text" "_j" "_c" (list (- xb8 3) (+ yb1 (/ (distance b1 b2) 2))) (* 0.18 sc) 90 (fix(distance b8 b9)) "")
  (command "_text" "_j" "_c" (list (+ xb10 (/ (distance b10 b9) 2)) (- yb2 di)) (* 0.18 sc) 0 (fix(distance b10 b9)) "")

  ; ferri posizione n. 6; vengono stampati solo se s2  maggiore di zero (cio se c' il "dente")
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xb20 (* di 2.0)) yb19) (* 0.18 sc) 90 "Pos.6 -  %%C  /mt LT=")
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xb20 (* di 2.0)) (+ yb19 (* 3.9 di))) (* 0.18 sc) 90 (rtos nf 2 0)); scrive il numero dei ferri "nf"
  )  
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xb20 (* di 2.0)) (+ yb19 (* 5.5 di))) (* 0.18 sc) 90 (rtos fi 2 0)); scrive il diametro
  ) 
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xb20 (* di 2.0)) (+ yb19 (* (* 0.18 sc) 18))) (* 0.18 sc) 90 (fix(+ (distance a10 a9) (distance a9 a7) (distance a7 a11) (distance a11 a10) (distance b21 b22)))); scrive la lunghezza totale del ferro in pos. 6
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" "_j" "_c" (list (+ xb19 (/ (distance a10 a9) 2)) (- yb19 di)) (* 0.18 sc) 0 (fix(distance a10 a9)))
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" "_j" "_c" (list (+ xb19 (/ (distance a10 a9) 2)) (+ yb20 3)) (* 0.18 sc) 0 (fix(distance a10 a9)))
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" "_j" "_c" (list (- xb19 3) (+ yb19 (/ (distance a10 a11) 2))) (* 0.18 sc) 90 (fix(distance a10 a11)))  
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" "_j" "_c" (list (+ xa9 di) (+ yb19 (/ (distance a10 a11) 2))) (* 0.18 sc) 90 (fix(distance a10 a11)))
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" "_j" "_c" (list (- xb22 3) (+ yb22 (/ (distance b22 b21) 2))) (* 0.18 sc) 90 (fix(distance b22 b21)))
  )

  ; stampa dati generali: copriferro, tipo di cls e acciaio, volume cls, scala del disegno
  (command "_text" (list xb1 yb13) (* 0.18 sc) 0 "Copriferro (cm)= ")
  (command "_text" (list (+ xb1 (* (* 0.18 sc) 15)) yb13) (* 0.18 sc) 0 (fix cf))
  (command "_text" (list xb1 (- yb13 (* 2 di))) (* 0.18 sc) 0 "Calcestruzzo Rck 30 kN/mmq")
  (command "_text" (list xb1 (- yb13 (* 4 di))) (* 0.18 sc) 0 "Volume cls (mc/ml)= ")

  ; vengono definite delle variabili per il calcolo dell'area del muro

  (setq area5 (* (distance p2 p3) (distance p3 p4))
        area4 (* (distance p6 p5) (distance p6 p7))
        area3 (* (distance p8 p9) (distance p9 p4))
        area2 (* (distance p1 p2) (distance p2 p3))
        area1 (- (* (distance p1 p10) 0.5 (+ (distance p1 p2) (distance p10 p3))) area2)
        areat (+ area1 area2 area3 area4) ;areat = area totale del muro 
  )

  (command "_text" (list (+ xb1 (* (* 0.18 sc) 18)) (- yb13 (* 4 di))) (* 0.18 sc) 0 (rtos (* areat 0.0001) 2 2))

  ; N.B.: la funzione "rtos" consente di eliminare gli zeri dopo i decimali (=Real To String, trasforma un numero in stringa)
  ; il formato della funzione : (rtos, valore [, modalit, precisione])
  ; [modalit] = tipo di notazione. La notazione decimale  uguale a 2
  ; [precisione] = imposta il numero di cifre dopo il punto decimale 

  (command "_text" (list xb1 (- yb13 (* 9 di))) (* 0.18 sc) 0 "Scala 1:")
  (command "_text" (list (+ xb1 (* (* 0.18 sc) 7)) (- yb13 (* 9 di))) (* 0.18 sc) 0 (fix sc))

  ; *******************************************************************   
  ; Disegno della distinta delle armature (conforme alla UNI 9120)
  ; *******************************************************************

  ; viene creato il layer "3", di colore verde, in cui verr disegnata la distinta dei ferri d'armatura

    (command "_-layer"
             "_make"
             3
             "_color"
             3
             3
             _end
     )

  ; viene richiamato il blocco contenente la distinta armature. Se  presente il dente di fondazione (s2 > 0) e (S1 > 0) il blocco 
  ; si chiama "D1-6", altrimenti "D1".

  (if (and (> s2 0) (> s1 0))
     (command "-insert"
      "D1-6"
     (list (+ xb9 (* 4 di)) yb9)
     sc
     sc
     ""
     )          
  )

  (if (and (= s2 0) (= s1 0))
     (command "-insert"
      "D1"
     (list (+ xb9 (* 4 di)) yb9)
     sc
     sc
     ""
     )          
  )

  ; Compilazione della tabella dei ferri
  ; ************************************

  ; Vengono fissate le coordinate x e y del punto di inserimento della tabella, in modo da riferire ad esse tutti
  ; i punti di inizio dei testi interni alla tabella

   (setq    xinser (+ xb9 (* 4 di))
            yinser (+ yb9 0)
   )

  ; Assegnazione dei pesi unitari per i vari diametri (kg/ml) attraverso la variabile 'peso'

  (if (= fi 8) (setq peso 0.395)) ;  peso per fi = 8
  (if (= fi 9) (setq peso 0.499)) ;  peso per fi = 9
  (if (= fi 10) (setq peso 0.617));  peso per fi = 10
  (if (= fi 11) (setq peso 0.746));  peso per fi = 11
  (if (= fi 12) (setq peso 0.888));  peso per fi = 12
  (if (= fi 13) (setq peso 1.042));  peso per fi = 13
  (if (= fi 14) (setq peso 1.208));  peso per fi = 14
  (if (= fi 15) (setq peso 1.387));  peso per fi = 15
  (if (= fi 16) (setq peso 1.578));  peso per fi = 16
  (if (= fi 17) (setq peso 1.782));  peso per fi = 17
  (if (= fi 18) (setq peso 1.998));  peso per fi = 18
  (if (= fi 19) (setq peso 2.226));  peso per fi = 19
  (if (= fi 20) (setq peso 2.466));  peso per fi = 20
  (if (= fi 21) (setq peso 2.719));  peso per fi = 21
  (if (= fi 22) (setq peso 2.984));  peso per fi = 22
  (if (= fi 23) (setq peso 3.262));  peso per fi = 23
  (if (= fi 24) (setq peso 3.551));  peso per fi = 24
  (if (= fi 25) (setq peso 3.853));  peso per fi = 25
  (if (= fi 26) (setq peso 4.168));  peso per fi = 26
  (if (= fi 27) (setq peso 4.495));  peso per fi = 27
  (if (= fi 28) (setq peso 4.834));  peso per fi = 28
  (if (= fi 29) (setq peso 5.185));  peso per fi = 29
  (if (= fi 30) (setq peso 5.549));  peso per fi = 30

  ; Compilazione della riga 1 - Posizione 1
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 1

  (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  (setq L1 (* (fix(+ (distance b11 b12) (distance b12 b13) (distance b13 b14))) 0.01)); L1 = Lunghezza del ferro in pos. 1 (in m)
  (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos L1 2 2)) ; scrive la L. del ferro in pos. 1
  (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 1
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos (* L1 nf) 2 2)); scrive la L. T. ferri in pos. 1
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos (* L1 nf peso) 2 2)); peso totale ferri in pos. 1
  (setq aa1 (* (fix (distance b12 b13)) 0.01)); aa1 = Lunghezza "a" del ferro in pos. 1 (in m)
  (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos aa1 2 2)) ;scrive la "a" del ferro in pos. 1
  (setq bb1 (* (fix (distance b13 b14)) 0.01)); bb1 = Lunghezza "b" del ferro in pos. 1 (in m)
  (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 2.16 sc))) (* 0.18 sc) 0 (rtos bb1 2 2)) ;scrive la "b" del ferro in pos. 1

  ; Compilazione della riga 2 - Posizione 2
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 2

  (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  (setq L2 (* (fix(+ (distance b11 b12) (distance b12 b13) (distance b13 b14))) 0.01)); L2 = Lunghezza del ferro in pos. 2 (in m)
  (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos L2 2 2)) ; scrive la L. del ferro in pos. 2
  (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 2
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos (* L2 nf) 2 2)); scrive la L. T. ferri in pos. 2
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos (* L2 nf peso) 2 2)); peso totale ferri in pos. 2
  (setq aa2 (* (fix (distance b12 b13)) 0.01)); aa2 = Lunghezza "a" del ferro in pos. 2 (in m)
  (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos aa2 2 2)) ;scrive la "a" del ferro in pos. 2
  (setq bb2 (* (fix (distance b13 b14)) 0.01)); bb2 = Lunghezza "b" del ferro in pos. 2 (in m)
  (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 2.88 sc))) (* 0.18 sc) 0 (rtos bb2 2 2)) ;scrive la "b" del ferro in pos. 2

  ; Compilazione della riga 3 - Posizione 3
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 3

  (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  (setq L3 (* (fix(+ (distance b4 b5) (distance b5 b6) (distance b6 b7))) 0.01)); L3 = Lunghezza del ferro in pos. 3 (in m)
  (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos L3 2 2)) ; scrive la L. del ferro in pos. 3
  (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 3
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos (* L3 nf) 2 2)); scrive la L. T. ferri in pos. 3
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos (* L3 nf peso) 2 2)); peso totale ferri in pos. 3
  (setq aa3 (* (fix (distance b5 b6)) 0.01)); aa3 = Lunghezza "a" del ferro in pos. 3 (in m)
  (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos aa3 2 2)) ;scrive la "a" del ferro in pos. 3
  (setq bb3 (* (fix (distance b4 b5)) 0.01)); bb3 = Lunghezza "b" del ferro in pos. 3 (in m)
  (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 3.60 sc))) (* 0.18 sc) 0 (rtos bb3 2 2)) ;scrive la "b" del ferro in pos. 3

  ; Compilazione della riga 4 - Posizione 4
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 4

  (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  (setq L4 (* (fix(+ (distance b10 b9) (distance b8 b9))) 0.01)); L4 = Lunghezza del ferro in pos. 4 (in m)
  (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos L4 2 2)) ; scrive la L. del ferro in pos. 4
  (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 4
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos (* L4 nf) 2 2)); scrive la L. T. ferri in pos. 4
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos (* L4 nf peso) 2 2)); peso tot. ferri in pos. 4
  (setq aa4 (* (fix (distance b8 b9)) 0.01)); aa4 = Lunghezza "a" del ferro in pos. 4 (in m)
  (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos aa4 2 2)) ;scrive la "a" del ferro in pos. 4
  (setq bb4 (* (fix (distance b9 b10)) 0.01)); bb4 = Lunghezza "b" del ferro in pos. 4 (in m)
  (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos bb4 2 2)) ;scrive la "b" del ferro in pos. 4
  (setq cc4 (* (fix (- xb2 xb1)) 0.01)); cc4 = Lunghezza "c" del ferro in pos. 4 (in m)
  (command "_text" (list (+ xinser (* sc 17.00)) (- yinser (* 4.32 sc))) (* 0.18 sc) 0 (rtos cc4 2 2)) ;scrive la "c" del ferro in pos. 4

  ; Compilazione della riga 5 - Posizione 5
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 5

  (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  (setq L5 (* (fix(+ (distance b10 b9) (distance b8 b9))) 0.01)); L5 = Lunghezza del ferro in pos. 5 (in m)
  (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos L5 2 2)) ;scrive la L. del ferro in pos. 5
  (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 5
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos (* L5 nf) 2 2)); scrive la L. T. ferri in pos. 5
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos (* L5 nf peso) 2 2)); peso tot. ferri in pos. 5
  (setq aa5 (* (fix (distance b8 b9)) 0.01)); aa5 = Lunghezza "a" del ferro in pos. 5 (in m)
  (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos aa5 2 2)) ;scrive la "a" del ferro in pos. 5
  (setq bb5 (* (fix (distance b9 b10)) 0.01)); bb5 = Lunghezza "b" del ferro in pos. 5 (in m)
  (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 5.04 sc))) (* 0.18 sc) 0 (rtos bb5 2 2)) ;scrive la "b" del ferro in pos. 5

  ; Compilazione della riga 6 - Posizione 6 (SOLO SE E' PRESENTE IL DENTE DI FONDAZIONE)
  ; ************************************
  ; Viene compilata la riga corrispondente alla posizione n. 6
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 5.60)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (fix fi)) ; viene scritto il diametro 'fi'
  )
  (if (and (> s2 0) (> s1 0))
     (setq L6 (* (fix(+ (distance a10 a9) (distance a9 a7) (distance a7 a11) (distance a11 a10) (distance b21 b22))) 0.01)); L6 = Lunghezza 6
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 6.45)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos L6 2 2)) ; viene scritta la L. del ferro 6
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 7.55)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos peso 2 3)); peso unitario del ferro pos. 6
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos nf 2 0)); scrive il numero ferri "nf"
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos (* L6 nf) 2 2)); scrive la L. T. ferri pos. 6
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos (* L6 nf peso) 2 2)); peso tot. ferri pos. 6
  )
  (if (and (> s2 0) (> s1 0))
     (setq aa6 (* (fix (distance a11 a10)) 0.01)); aa6 = Lunghezza "a" del ferro in pos. 6 (in m)
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 15.65)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos aa6 2 2)) ;scrive la "a" ferro in pos. 6
  )
  (if (and (> s2 0) (> s1 0))
     (setq bb6 (* (fix (distance a10 a9)) 0.01)); bb6 = Lunghezza "b" del ferro in pos. 6 (in m)
  )
  (if (and (> s2 0) (> s1 0))
     (command "_text" (list (+ xinser (* sc 16.36)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos bb6 2 2)) ;scrive la "b" ferro in pos. 6
  )


  ; Compilazione della riga R.P. - Ripartirori Parete verticale
  ; ************************************
  ; Viene compilata la riga corrispondente ai Ripartirori della Parete verticale

  (setq RP (fix (* (/ aa5 0.20) 2))) ; calcola in numero di ferri RP con la condizione di 1 ferro ogni 0.20 metri x 2
  ;
  ; <<<<<< N.B. I FERRI RIPARTITORI SONO DISPOSTI SUI DUE LATI DELLA PARETE (A MONTE E A VALLE DEL MURO) >>>>>>>
  ;
  ; nota: vengono distinti i due casi (con dente e senza dente di fondazione) solo per questioni di visualizzazione dei dati
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos RP 2 0)); il numero dei ferri R.P.
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos RP 2 0)); il numero dei ferri R.P.
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos RP 2 2)); scrive la L. T. dei ferri R.P.
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos RP 2 2)); scrive la L. T. dei ferri R.P.
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos (* RP 0.617) 2 2)); peso tot. ferri RP
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 5.76 sc))) (* 0.18 sc) 0 (rtos (* RP 0.617) 2 2)); peso tot. ferri RP
  )

  ; Compilazione della riga R.F. - Ripartirori Fondazione
  ; ************************************
  ; Viene compilata la riga corrispondente ai Ripartirori della Fondazione

  ; nel caso ci sia il dente di fondazione il numero di ripartitori va aumentato di 2, per considerare i reggistaffa del "dente";
  (if (and (> s2 0) (> s1 0))
  (setq RF (+ (fix (* (/ aa1 0.20) 2)) 1)) ; calcola in numero di ferri RF con la condizione di 1 ferro ogni 0.20 metri x 2
  )

  ; numero di ripartitori di fondazione nel caso NON ci sia il "dente" di fondazione;
  (if (and (= s2 0) (= s1 0))
  (setq RF (fix (* (/ aa1 0.20) 2))) ; calcola in numero di ferri RF con la condizione di 1 ferro ogni 0.20 metri x 2
  )

  ; <<<<<< N.B. I FERRI RIPARTITORI SONO DISPOSTI SUI DUE LATI DELLA FONDAZIONE >>>>>>>
  ;
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 7.20 sc))) (* 0.18 sc) 0 (rtos RF 2 0)); il numero dei ferri R.F.
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 8.80)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos RF 2 0)); il numero dei ferri R.F.
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 7.20 sc))) (* 0.18 sc) 0 (rtos RF 2 2)); scrive la L. T. dei ferri R.F.
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 9.55)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos RF 2 2)); scrive la L. T. dei ferri R.F.
  )
  (if (and (> s2 0) (> s1 0))
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 7.20 sc))) (* 0.18 sc) 0 (rtos (* RF 0.617) 2 2)); peso tot. ferri RF
  )
  (if (and (= s2 0) (= s1 0))
  (command "_text" (list (+ xinser (* sc 10.50)) (- yinser (* 6.48 sc))) (* 0.18 sc) 0 (rtos (* RF 0.617) 2 2)); peso tot. ferri RF
  )

  ; Scrittura del peso totale delle armature
  ; ************************************

  (command "_-layer" "_set" 2 "" _end) ; setta il layer 2 come corrente
  (command "_text" (list xb1 (- yb13 (* 6 di))) (* 0.18 sc) 0 "Acciaio FeB 44k - Peso per metro di muro (kg/ml) = ")
  (if (or (= s2 0) (= s1 0)) (setq L6 0))
  (command "_text" (list (+ xb1 (* 29 di)) (- yb13 (* 6 di))) (* 0.18 sc) 0 (rtos (+ (* (+ L1 L2 L3 L4 L5 L6) peso 5) (* RP 0.617) (* RF 0.617)) 2 2))

  ; *******************************************************************   
  ; Fine disegno della distinta delle armature (conforme alla UNI 9120)
  ; *******************************************************************


  ; viene riattivato lo snap

  (command "_-osnap"
           "_End,_Cen,_Node,_Int"
  )

  ; esegue uno zoom su tutta l'estensione del disegno

   (command "_zoom" "_extents")

  )

  ; --------------------------------------------------------------------------------------- Fine funzione draw_wall

  ;----------------------------------------------------------------------------------------
  ; funzione "draw_error" -  la funzione che ricerca eventuali errori nell'input

  (defun draw_error ()

       ;------------------------------
       ; controlla se l'altezza del muro  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= h 0) (< h 0)) (alert "L'altezza 'h' del muro deve essere maggiore di zero..."))                
       ;------------------------------
       ;------------------------------
       ; controlla se la sommit del muro  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= a 0) (< a 0)) (alert "La sommit 'a' del muro deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se il piede del muro  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= p 0) (< p 0)) (alert "Il piede 'p' del muro deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se lo spessore della soletta  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= d 0) (< d 0)) (alert "Lo spessore 'd' della soletta deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se la base esterna  minore di zero: in tal caso produce un messaggio di errore
       (if (< b 0) (alert "La base esterna 'b' non pu essere minore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se la base interna  minore di zero: in tal caso produce un messaggio di errore
       (if (< c 0) (alert "La base interna 'c' non pu essere minore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se l'altezza s2  minore di zero: in tal caso produce un messaggio di errore
       (if (< s2 0) (alert "L'altezza dente 's2' non pu essere minore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se la larghezza s1  minore di zero: in tal caso produce un messaggio di errore
       (if (< s1 0) (alert "La larghezza dente 's1' non pu essere minore di zero..."))
       ;------------------------------
       ; controlla che non capiti che s1=0 e s2 diverso da zero (o viceversa): in tal caso produce un messaggio di errore
       (if (or (and (> s1 0) (= s2 0)) (and (= s1 0) (> s2 0))) (alert "I valori di s1 e s2 devono essere o entrambi nulli o entrambi diversi da zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se il diametro dei ferri d'armatura  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= fi 0) (< fi 0)) (alert "Il diametro 'fi' dei ferri deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se il numero dei ferri d'armatura  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= nf 0) (< nf 0)) (alert "Il numero 'nf' di ferri/metro deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se il copriferro  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= cf 0) (< cf 0)) (alert "Il copriferro 'cf' deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; controlla se la scala di stampa  zero o minore di zero: in tal caso produce un messaggio di errore
       (if (or (= sc 0) (< sc 0)) (alert "La scala 'sc' di stampa deve essere maggiore di zero..."))
       ;------------------------------
       ;------------------------------
       ; se tutte le condizioni sono rispettate pone "done_dialog" uguale a 1
       (if (and (> h 0) (> a 0) (> p 0) (> d 0) (or (= b 0) (> b 0)) (or (= c 0) (> c 0)) (or (> s1 0) (= s1 0)) (or (> s2 0) (= s2 0))(or (and (> s1 0) (> s2 0)) (and (= s1 0) (= s2 0))) (> fi 0) (> nf 0) (> cf 0) (> sc 0)) (done_dialog 1))

   )

  ;--------------------------------------------------------------------------------------------
  ; Quando viene premuto il pulsante "Disegna" vengono letti (con l'istruzione "get_tile") i valori contenuti nelle caselle di dialogo. 
  ; Tali valori sono in realt stringhe di testo, pertanto con la funzione "atof" vengono trasformati in numeri reali e con "setq" 
  ; assegnati alle variabili h, a, p ecc..
  ; Tali variabili saranno utilizzate dalla funzione "draw_wall" per il disegno del muro.

  (action_tile "disegna"                         
                             "(setq h (atof (get_tile \"h\")))
                              (setq a (atof (get_tile \"a\")))
                              (setq p (atof (get_tile \"p\")))
                              (setq b (atof (get_tile \"b\")))
                              (setq c (atof (get_tile \"c\")))
                              (setq d (atof (get_tile \"d\")))
                              (setq s2 (atof (get_tile \"s2\")))
                              (setq s1 (atof (get_tile \"s1\")))
                              (setq fi (atof (get_tile \"fi\")))
                              (setq nf (atof (get_tile \"nf\")))
                              (setq cf (atof (get_tile \"cf\")))
                              (setq sc (atof (get_tile \"sc\")))
                              (draw_error)"    
   ) 
                             
  ;--------------------------------------------------------------------------------------------
  ; esce quando viene premuto il pulsante "Esci"

  (action_tile "esci" "(done_dialog 0)")

  ;--------------------------------------------------------------------------------------------
  ; carica l'help in linea (file wall.hlp) quando viene premuto il pulsante "Help"

  (action_tile "help" "(help \"wall\")")

  ;-------------------------------------------------------------------------------------------- 
  
  ;--------------------------------------------------------------------------------------------
  ; viene attivata la finestra di dialogo principale

    (setq Dialog_Status (start_dialog))

  ;--------------------------------------------------------------------------------------------
  ; viene disattivata la finestra di dialogo 

   (unload_dialog dcl_id)

  ;--------------------------------------------------------------------------------------------  
 
  ;--------------------------------------------------------------------------------------------
  ; Verifica che la variabile "Dialog_Status", restituita da "Start_Dialog" (che a sua volta la riceve da "Done_Dialog") sia pari ad 1, 
  ; in modo da attivare la funzione "draw_wall" per il disegno del muro.

  (cond
      ((= Dialog_Status 1)  ; se Done_dialog =1 esegue la funzione di disegno "draw_wall"
        (draw_wall)                
      )
   )
  
  (princ)

)